import abc
import builtins
import datetime
import enum
import typing

import jsii
import jsii.compat
import publication

import aws_cdk.aws_certificatemanager._jsii
import aws_cdk.aws_cloudfront._jsii
import aws_cdk.aws_iam._jsii
import aws_cdk.aws_route53._jsii
import aws_cdk.aws_route53_targets._jsii
import aws_cdk.aws_s3._jsii
import aws_cdk.core._jsii
import aws_cdk.region_info._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "@aws-cdk/aws-route53-patterns",
    "1.61.1",
    __name__[0:-6],
    "aws-route53-patterns@1.61.1.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
